from setuptools import setup, find_packages

setup(
    name="WdSpider",
    version="0.0.3",
    author="SongMingYu",
    author_email="1449065358@qq.com",
    description="This is my bag",
    # 项目主页
    url="https://gitee.com/song-mingyu-a/p9-operation",
    # 你要安装的包，通过 setuptools.find_packages 找到当前目录下有哪些包
    packages=find_packages()
)
